@extends('layouts.app')
@section('htmlheader_title')
	About
@endsection

@section('content')
	<h2>About the FTN Clearing House</h2>

	<p>Welcome to the FTN Clearing House.</p>

	<div class="float-end" id="network_traffic"></div>
	<p>The FTN Clearing House (FCH) is both a FTN Mailer and FTN message tosser, where mail is stored internally in a DB. FCH can also hatch and toss files into FTN networks for both up/downstream nodes.</p>
	<p>It was created as an idea to bring modern technology and capabilities to a legacy computing network that existed in the 1970's, 1980's and 1990's (before the Internet basically).</p>

	<p>Setting up a BBS is fun, but using a BBS for the long term, in amongst our busy lives can involve some repetitive tasks.
		In the same vain, maintaining and growing an FTN network also can be time consuming, especially when your effort (or lack thereof) can affect the experience of your users.
		So FCH was created to help address that.
	</p>

	<p>Building this software is driven by three main goals:</p>
	<ul>
		<li>Self Service - so that users can setup and re-jig their configuration themselves, or new users can join a network with the minimum of effort.</li>
		<li>Automation - so that repetitive tasks can be done with minimal effort</li>
		<li>High Availability - So if one hub goes down, users can automatically connect to an alternate hub to keep mail flowing. Furthermore, as hubs retire, new hubs can assume the role of the retiring hub with minimal effort.</li>
	</ul>

	<p>So that you can spend your time playing on your BBS rather than managing messages, failures or keeping an FTN network running.</p>

	<h3>For the BBS Sysop</h3>
	<p>For the BBS sysop, the FTN Clearing House has the following features (or planned ones):</p>
	<ul>
		<li>Supports BINKP network transfers</li>
		<li>Supports EMSI network transfers</li>
		<li>Supports PING responses</li>
		<li>A consistent reliable echomail/netmail hub for your BBSes.<br>
If you have more than 1 BBS, then the Clearing House can receive all your mail from your uplinks and feed them to your BBSes.
		</li>
	</ul>

	<h3>For the FTN network operator</h3>
	<p>For the FTN network operator, the FTN Clearing House has the following features (or planned ones):</p>
	<ul>
		<li>Supports BINKP network transfers</li>
		<li>Supports EMSI network transfers</li>
		<li>Automatic route configuration</li>
		<li>Manages ECHO areas and FILE areas <sup>To be implemented</sup></li>
		<li>Supports PING and TRACE responses <sup>To be implemented</sup></li>
		<li>Nodelist Management <sup>To be implemented</sup></li>
		<li>Network Applications <sup>To be implemented</sup></li>
		<li>Dynamic mail bundling for upstream and downstream nodes</li>
		<li>Automatic delisting of idle nodes <sup>To be implemented</sup></li>
	</ul>

	<h5>Other things</h5>
	<p>Other ideas that may make it into this tool:</p>
	<ul>
		<li>SMTP integration</li>
		<li>PGP signed mail and mail verification</li>
		<li>SQRL simple authentication <small>(so there is 1 less username/password you need to remember)</small></li>
	</ul>

	<p>To get started, please <a href="{{ url('login') }}">login</a>.</p>

	<h4>Open Source</h4>
	<p>FTN Clearing House is built with Open Source software. At it's core, PHP drives this web UI and the interaction with nodes.</p>
	<p>This web UI has been inspired by the great work at <a href="https://int10h.org">int10h.org</a>. If you have ideas to make it even better, please send me a message, or submit your comments in <a href="https://dev.leenooks.net/bbs/clrghouz">gitlab</a></p>

	<h4>Other technology that drives the Clearing Houz</h4>
	<p>FCH is made availabe by these technologies:</p>
	<ul>
		<li>Docker - taking the effort out of building, deploying and easing the effort of upgrading.</li>
		<li>CockroachDB - a high available, geodispersable database, that enables accessing configuration and data from multiple locations. CockroachDB enables the FCH to appear as the same hub from multiple locations, providing a high available environment for Sysops to drop off and collect mail</li>
		<li>Memcached - to take some of the pressure off CockroachDB</li>
		<li>PHP/Laravel - the coding framework used to create this UI, and to enable the transfer of mail between systems</li>
		<li>jQuery - to help with the web UI</li>
		<li>Highcharts - to render the graphs</li>
	</ul>

	<span class="float-end"><strong class="highlight">clrghouz</strong> <small>[<strong class="gray">{{ gethostname() }}</strong>@if (File::exists('../VERSION')) @ <strong class="success">{{ chop(File::get('../VERSION')) }}</strong>@endif]</small></span>
@endsection

@section('page-scripts')
	@js('highcharts')

	<script>
		Highcharts.chart('network_traffic', {
			chart: {
				type: 'spline',
				zoomType: 'x',
				resetZoomButton: {
					position: {
						x: 0,
						y: -40,
					}
				}
			},
			credits: {
				enabled: false
			},
			exporting: {
				buttons: false
			},
			title: {
				text: 'FTN Network Traffic'
			},
			xAxis: {
				type: 'datetime',
				title: {
					text: 'Time'
				},
			},
			yAxis: {
				title: {
					text: 'Echomail'
				},
			},
			legend: {
				symbolWidth: 40
			},
			plotOptions: {
				series: {
					point: {
						events: {
							click: function () {
								//window.location.href = this.series.options.website;
							}
						}
					},
					cursor: 'pointer'
				}
			},
			series: [
				@foreach (\App\Models\Domain::active()->public()->orderBy('name')->with(['echoareas'])->get() as $o)
				{
					name: '{{ $o->name }}',
					data: {!! $o->daily_area_stats() !!},
					dashStyle: 'ShortDot',
				},
				@endforeach
			],
		});
	</script>
@append